==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SidecarListFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SidecarListFluent<A extends SidecarListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Sidecar item);
  public A setToItems(Integer index,Sidecar item);
  public A addToItems(io.fabric8.istio.api.networking.v1alpha3.Sidecar... items);
  public A addAllToItems(Collection<Sidecar> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1alpha3.Sidecar... items);
  public A removeAllFromItems(Collection<Sidecar> items);
  public A removeMatchingFromItems(Predicate<SidecarBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Sidecar> getItems();
  public List<Sidecar> buildItems();
  public Sidecar buildItem(Integer index);
  public Sidecar buildFirstItem();
  public Sidecar buildLastItem();
  public Sidecar buildMatchingItem(Predicate<SidecarBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SidecarBuilder> predicate);
  public A withItems(List<Sidecar> items);
  public A withItems(io.fabric8.istio.api.networking.v1alpha3.Sidecar... items);
  public Boolean hasItems();
  public SidecarListFluent.ItemsNested<A> addNewItem();
  public SidecarListFluent.ItemsNested<A> addNewItemLike(Sidecar item);
  public SidecarListFluent.ItemsNested<A> setNewItemLike(Integer index,Sidecar item);
  public SidecarListFluent.ItemsNested<A> editItem(Integer index);
  public SidecarListFluent.ItemsNested<A> editFirstItem();
  public SidecarListFluent.ItemsNested<A> editLastItem();
  public SidecarListFluent.ItemsNested<A> editMatchingItem(Predicate<SidecarBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SidecarFluent<SidecarListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SidecarListFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SidecarListFluent<A extends SidecarListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Sidecar item);
  public A setToItems(int index,Sidecar item);
  public A addToItems(io.fabric8.istio.api.networking.v1alpha3.Sidecar... items);
  public A addAllToItems(Collection<Sidecar> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1alpha3.Sidecar... items);
  public A removeAllFromItems(Collection<Sidecar> items);
  public A removeMatchingFromItems(Predicate<SidecarBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Sidecar> getItems();
  public List<Sidecar> buildItems();
  public Sidecar buildItem(int index);
  public Sidecar buildFirstItem();
  public Sidecar buildLastItem();
  public Sidecar buildMatchingItem(Predicate<SidecarBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SidecarBuilder> predicate);
  public A withItems(List<Sidecar> items);
  public A withItems(io.fabric8.istio.api.networking.v1alpha3.Sidecar... items);
  public Boolean hasItems();
  public SidecarListFluent.ItemsNested<A> addNewItem();
  public SidecarListFluent.ItemsNested<A> addNewItemLike(Sidecar item);
  public SidecarListFluent.ItemsNested<A> setNewItemLike(int index,Sidecar item);
  public SidecarListFluent.ItemsNested<A> editItem(int index);
  public SidecarListFluent.ItemsNested<A> editFirstItem();
  public SidecarListFluent.ItemsNested<A> editLastItem();
  public SidecarListFluent.ItemsNested<A> editMatchingItem(Predicate<SidecarBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SidecarFluent<SidecarListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
